@@ -8,7 +8,7 @@ from _state import *        # noqa
 from _store import *        # noqa
 import _dbm as dbm          # noqa
 import _exc as exc          # noqa
+import _auth as auth        # noqa
 import _wsgi as wsgi        # noqa
-import _admin as admin      # noqa
 import _server as server    # noqa
 import _config as config    # noqa
