@@ -7,10 +7,27 @@ from _term import is_module, is_str
 import logging
 logger = logging.getLogger('fanery.autoreload')
 
+# modules selected for autoreloading
+_modules_autoreload = set()
+
 # modules files stats
 _mf_stats = dict()
 
 
+def observe_module(term):
+    module = term if is_module(term) else getmodule(term)
+    while module not in _modules_autoreload:
+        _modules_autoreload.add(module)
+        name = module.__name__.split('.', 1)[0]
+        module = __import__(name, None, None, name)
+    else:
+        trigger_autoreload()
+
+
+def trigger_autoreload():
+    map(deep_reload, _modules_autoreload)
+
+
 def deep_reload(module, loaded=None, parent=None):
     """Deep reload of module.
 
@@ -40,10 +57,14 @@ def deep_reload(module, loaded=None, parent=None):
             if is_module(member) and member not in loaded:
                 deep_reload(member, loaded, parent)
             try:
-                m_file = module.__file__
+                m_file, m_ext = module.__file__.rsplit('.', 1)
+                m_file = '%s.%s' % (m_file, m_ext[:2])
                 m_mtime = stat(m_file).st_mtime
                 if m_file in _mf_stats and m_mtime > _mf_stats[m_file]:
+                    logger.debug('reload %s' % module)
                     reload(module)
+                elif m_file not in _mf_stats:
+                    logger.debug('observe %s' % m_file)
                 _mf_stats[m_file] = m_mtime
                 loaded.add(module)
             except:
