@@ -10,6 +10,7 @@ from _crypto import (
     nacl_nonce, nacl_random, nacl_sha256,
     PrivateKey, PublicKey, Box, SigningKey
 )
+from _autoreload import observe_module
 from _auth import hooks as auth
 from _state import get_state
 import _config as conf
@@ -74,8 +75,8 @@ def service(urlpath=None, auto_parse=True, static=False, accel=False,
         if not (k and k.isalnum() and callable(v)):
             raise exc.InvalidOutputFormatter(k, v)
     else:
-        output.setdefault('json', to_json)
-        output.setdefault('txt', to_str)
+        output.setdefault('json', lambda t: to_json(to_simple(t)))
+        output.setdefault('txt', lambda t: to_str(to_simple(t)))
         output.setdefault('raw', repr)
 
     if not safe:
@@ -85,17 +86,23 @@ def service(urlpath=None, auto_parse=True, static=False, accel=False,
         srv_path = (urlpath or f.__name__).strip('/')
 
         if srv_path in registry:
-            if force_define is True or conf.MODULES_AUTORELOAD:
-                logger.debug("redefine service '%s' %s" % (srv_path, f))
+            if force_define is True or conf.IS_DEVELOPMENT:
+                logger.debug("redefine <%s> for %s() in %s line %d" % (
+                    srv_path,
+                    f.func_code.co_name,
+                    f.func_code.co_filename,
+                    f.func_code.co_firstlineno))
             else:
                 raise exc.MultipleDefine(srv_path)
+        elif conf.IS_DEVELOPMENT:
+            observe_module(f)
 
         @wraps(f)
         def wrapper(*args, **argd):
 
             _state_ = get_state()
 
-            if ssl is not False and (conf.USE_SSL or ssl) and not _state_.ssl:
+            if ssl is not False and (not conf.IS_DEVELOPMENT or ssl) and not _state_.ssl:   # noqa
                 raise exc.RequireSSL(srv_path)
 
             domain = _state_.domain
