@@ -1,15 +1,15 @@
-import logging
-logging.basicConfig(level=logging.ERROR)
-
 from fanery import (
     PyClient, WsgiClient,
     service,
     get_state,
     rand_num, rand_bytes,
     Hict, is_date,
-    exc
+    exc, config
 )
 
+import logging.config
+config.LOGGING['loggers']['fanery']['level'] = 'ERROR'
+logging.config.dictConfig(config.LOGGING)
 
 # -- services definition -----------------------------
 
@@ -152,13 +152,12 @@ def test_auto_parse_on_call():
 
 
 def test_lookup():
-    from fanery._term import to_json, to_str
     from fanery._service import lookup, static, registry
 
-    assert lookup('prefix/echo/1/2/3.json') == (echo, ['1', '2', '3'], '.json', to_json)  # noqa
+    assert lookup('prefix/echo/1/2/3.json')[:-1] == (echo, ['1', '2', '3'], '.json')    # noqa
     assert lookup('/echo.doc') == (echo, [], '.doc', False)
     assert lookup('/a/profile') == (profile, [], '', None)
-    assert lookup('profile.txt') == (profile, [], '.txt', to_str)
+    assert lookup('profile.txt')[:-1] == (profile, [], '.txt')
 
     if '' not in registry:
         assert lookup('/index.html') == (None, ['index.html'], '.html', None)
@@ -238,16 +237,8 @@ def main():
                #lambda: dbm.HDStore('192.168.122.91', 2001, indexer='self'),
                ):
 
-        ds = DS()
-        storage = DataStore(storage=ds,
-                            permission=ds,
-                            state=ds,
-                            abuse=ds,
-                            profile=ds,
-                            settings=ds)
-
         shuffle(tests)
-        timecall(setup)(storage)
+        timecall(setup)(DataStore(DS()))
         for name, test in tests:
             #memory_profile(test)()
             #line_profile(test)()
